==> crypto-2.6.1.tgz: package/Xem/Xem.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Xem = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zM6.145 11.954c.084.7.206 1.398.365 2.093.025.111.058.209.1.3a4.53 4.53 0 008.47-.671c.11-.395.163-.817.18-1.353a6.005 6.005 0 013.169-5.178 26.063 26.063 0 00-2.015-.14 20.221 20.221 0 00-6.262.852A20.035 20.035 0 006 9.637c.002.759.05 1.53.145 2.317zm16.613 8.56a20.147 20.147 0 003.164-9.215c.05-.57.076-1.123.078-1.664a19.598 19.598 0 00-1.356-.704c-.763-.357-1.389-.612-2.008-.807a4.468 4.468 0 00-2.437-.083 4.518 4.518 0 00-3.382 5.219c.244 1.306.937 2.318 2.074 3.04a7.075 7.075 0 00.239.146 5.933 5.933 0 012.147 2.262 5.91 5.91 0 01.729 2.89c.263-.353.514-.715.752-1.084zm-3.037 3.673a.581.581 0 00.118-.162l.044-.087c.09-.177.128-.251.172-.343.52-1.085.618-2.186.283-3.307a4.52 4.52 0 00-4.902-3.206 4.604 4.604 0 00-1.706.57 6.027 6.027 0 01-6.034-.013 20.346 20.346 0 004.063 6.031 20.375 20.375 0 003.225 2.691c.409.275.809.524 1.018.639a20.522 20.522 0 003.72-2.813z"
  }));
});
Xem.displayName = 'Xem';
export const XemDimensions = {
  height: 32,
  width: 32
};

==> crypto-2.7.1.tgz: package/Xem/Xem.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Xem = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 32 32"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    d: "M16 32C7.163 32 0 24.837 0 16S7.163 0 16 0s16 7.163 16 16-7.163 16-16 16zM6.145 11.954c.084.7.206 1.398.365 2.093.025.111.058.209.1.3a4.53 4.53 0 008.47-.671c.11-.395.163-.817.18-1.353a6.005 6.005 0 013.169-5.178 26.063 26.063 0 00-2.015-.14 20.221 20.221 0 00-6.262.852A20.035 20.035 0 006 9.637c.002.759.05 1.53.145 2.317zm16.613 8.56a20.147 20.147 0 003.164-9.215c.05-.57.076-1.123.078-1.664a19.598 19.598 0 00-1.356-.704c-.763-.357-1.389-.612-2.008-.807a4.468 4.468 0 00-2.437-.083 4.518 4.518 0 00-3.382 5.219c.244 1.306.937 2.318 2.074 3.04a7.075 7.075 0 00.239.146 5.933 5.933 0 012.147 2.262 5.91 5.91 0 01.729 2.89c.263-.353.514-.715.752-1.084zm-3.037 3.673a.581.581 0 00.118-.162l.044-.087c.09-.177.128-.251.172-.343.52-1.085.618-2.186.283-3.307a4.52 4.52 0 00-4.902-3.206 4.604 4.604 0 00-1.706.57 6.027 6.027 0 01-6.034-.013 20.346 20.346 0 004.063 6.031 20.375 20.375 0 003.225 2.691c.409.275.809.524 1.018.639a20.522 20.522 0 003.72-2.813z"
  }));
});
Xem.displayName = 'Xem';
export var XemDimensions = {
  height: 32,
  width: 32
};
